"""
Raw data for faker_music module (music.py) to mine from.
Data is presented in one big list of dicts, each dict
corresponding to a "instrument object":
{
    "category": "<category>",
    "instruments": [
        "<instrument1>",
        "<instrument2>",
        "<instrument3>",
        ...
    ]
}

This data was harvested on 2021-05-20, from 
https://en.wikipedia.org/wiki/List_of_musical_instruments
Author maintains code to format copy/pasted data;
please ask for link to gist
"""

instrument_list = [
    {
        "category": "percussion",
        "instruments": [
            "Aburukuwa",
            "Acme siren",
            "Afoxé",
            "Agogô",
            "Agung",
            "Agung a tamlang",
            "Alarm device",
            "Alfaia",
            "Alligator drum",
            "Angklung",
            "Anvil",
            "Apito",
            "Ashiko",
            "Atabaque",
            "Babendil",
            "Bak",
            "Balafon",
            "Bamboula",
            "Bara",
            "Bass drum",
            "Batá drum",
            "Beatboxing",
            "Bedug",
            "Bell",
            "Bell plate",
            "Bell tree",
            "Bendir",
            "Berimbau",
            "Bianzhong",
            "Binzasara",
            "Bo",
            "Bock-a-da-bock",
            "Bodhrán",
            "Body percussion",
            "Bombo criollo",
            "Bombo legüero",
            "Bonang",
            "Bones (instrument)",
            "Bongo drum",
            "Boobam",
            "Boomwhacker",
            "Bougarabou",
            "Bubon",
            "Buk",
            "Cabasa",
            "Cajón",
            "Cajón de rumba",
            "Calung",
            "Carimbo",
            "Candombe drums",
            "Cannon",
            "Cantaro",
            "Carillon",
            "Castanets",
            "Caxirola",
            "Caxixi",
            "Celesta",
            "Chácaras",
            "Chenda",
            "Chime bar",
            "Chime (bell instrument)",
            "China cymbal",
            "Cimbalom",
            "Clapper",
            "Clapping",
            "Clap stick",
            "Clash cymbals",
            "Claves",
            "Clavichord",
            "Clay drum",
            "Cocktail drum",
            "Conga",
            "Cowbell",
            "Crotale",
            "Crystallophone",
            "Cuíca",
            "Cup chime",
            "Cymbal",
            "Dabakan",
            "Daf",
            "Damaru",
            "Damphu",
            "Đàn tam thập lục",
            "Davul",
            "Daxophone",
            "Dayereh",
            "Den-den daiko",
            "Derkach",
            "Dhaa",
            "Dhimay",
            "Dholak",
            "Dhol",
            "Dimdi",
            "Djembe",
            "Dohol",
            "Dollu",
            "Đông Sơn drums",
            "Drum",
            "Drum stick",
            "Dunun",
            "Egg shaker",
            "Ekwe",
            "Electronic drum",
            "Esterilla",
            "Ferrinho",
            "Fiddlesticks",
            "Finger snapping",
            "Flexatone",
            "Flower drum",
            "Fontomfrom",
            "Found object",
            "Frame drum",
            "Friction drum",
            "Galgo",
            "Gandingan",
            "Ganzá",
            "Gbedu",
            "Gendèr",
            "Geophone",
            "Ghatam",
            "Glasschord",
            "Glass harmonica",
            "Glass harp",
            "Glockenspiel",
            "Goblet drum",
            "Goema",
            "Gong",
            "Gong bass drum",
            "Gonguê",
            "Gudugudu",
            "Güira",
            "Güiro",
            "Hammered dulcimer",
            "Handbell",
            "Handchime",
            "Hand-repique",
            "Handpan",
            "Hang",
            "Hi-hat",
            "Hosho",
            "Huiringua",
            "Hydraulophone",
            "Hyoshigi",
            "Igba",
            "Ikembe",
            "Ikoro",
            "Ilimba",
            "Jam block",
            "Janggu / Janggo / Changgo",
            "Jawbone",
            "Jaw harp",
            "Jhallari",
            "Jingle",
            "Junjung",
            "Kakko",
            "Kanjira",
            "Karyenda",
            "Kebero",
            "Kecer",
            "Kemanak",
            "Kempyang and ketuk",
            "Kendang",
            "Kenong",
            "Kepyak",
            "Keyboard glockenspiel",
            "Khim",
            "Khol",
            "Kirikoketa",
            "Kiringi",
            "Kisanji",
            "Klong khaek",
            "Klong yao",
            "Kouxian",
            "Kpanlogo",
            "Kulintang",
            "Kundu",
            "Kus",
            "Lambeg",
            "Lion's roar",
            "Lithophone",
            "Lujon",
            "Lummi stick",
            "Madal",
            "Maddale",
            "Madhalam",
            "Maktoum",
            "Makuta",
            "Malimbe",
            "Mangey",
            "Maraca",
            "Maram (drum)",
            "Marching machine",
            "Marfa",
            "Marimba",
            "Marímbula",
            "Mark tree",
            "Mbira",
            "Metallophone",
            "Mirwas",
            "Monkey stick",
            "Mridangam",
            "Musical saw",
            "Nagara",
            "Naqara",
            "Naqareh",
            "Naqus",
            "Ngoma drums",
            "North Drums",
            "Ocean drum",
            "Octa-Vibraphone",
            "Octoban",
            "Omele",
            "Onavillu",
            "Ōtsuzumi",
            "Padayani thappu",
            "Pahu",
            "Pahū pounamu",
            "Paiban",
            "Paila criolla",
            "Pakhavaj",
            "Pambai",
            "Pandeiro",
            "Pandero jarocho",
            "Pantalon",
            "Pellet drum",
            "Pixiphone",
            "Practice pad",
            "Plasmaphone",
            "Pyrophone",
            "Quadrangularis Reversum",
            "Quintephone",
            "Rainstick",
            "Rakatak",
            "Ranat ek",
            "Ranat ek lek",
            "Ranat thum",
            "Ranat thum lek",
            "Ratchet",
            "Rattle",
            "Ravanne",
            "Rebana",
            "Repique",
            "Ring of bells",
            "Ring-repique",
            "Ringing rocks",
            "Riq",
            "Rock gong",
            "Rototom",
            "Sabar",
            "Sakara",
            "Salterio",
            "Sambal",
            "Samphor",
            "Sand blocks",
            "Santoor",
            "Santur",
            "Saron",
            "Scabellum",
            "Semantron",
            "Shekere",
            "Shime-daiko",
            "Shishi-odoshi",
            "Shōko",
            "Sikulu",
            "Silex Piano",
            "Singing bowl",
            "Siren (alarm)",
            "Skrabalai",
            "Skull",
            "Sleigh bells",
            "Slenthem",
            "Slit drum",
            "Snare drum",
            "Song bells",
            "Sounding stone",
            "Spoon",
            "Steelpan",
            "Stomp box",
            "Stone marimba",
            "Suikinkutsu",
            "Surdo",
            "Suspended cymbal",
            "Taal",
            "Tabla",
            "Tabla tarang",
            "Taiko",
            "Talempong",
            "Talking drum",
            "Tambora",
            "Tamborim",
            "Tamborita calentana",
            "Tambourine",
            "Tan-tan",
            "Tap shoe",
            "Taphon",
            "Tar (drum)",
            "Tassa",
            "Taxi Horn",
            "Tbilat",
            "Teponaztli",
            "Thappu",
            "Thavil",
            "Thunder machine (instrument)",
            "Thunder sheet",
            "Tifa (drum)",
            "Timbal",
            "Timbales",
            "Timpani",
            "Tingsha",
            "Tom-tom drum",
            "Tombak",
            "Triangle",
            "Triccaballacca",
            "Tsuzumi",
            "Tsymbaly",
            "Tubular bells",
            "Tumba",
            "Turntable",
            "Tumdak'",
            "Turkish crescent",
            "Txalaparta",
            "Udu",
            "Vibraphone",
            "Vibraslap",
            "Washboard",
            "Whip",
            "Whistle",
            "Wind chime",
            "Wind machine",
            "Wobble board",
            "Wood block",
            "Wooden fish",
            "Xylophone",
            "Xylorimba",
            "Yangqin",
            "Yuka",
            "Zabumba",
            "Zatula",
            "Zill",
        ],
    },
    {
        "category": "winds",
        "instruments": [
            "Accordina (instrument)",
            "Accordion",
            "Accordola",
            "Air horn",
            "Alboka",
            "Algaita",
            "Alphorn",
            "Alto horn",
            "Arghul",
            "Atenteben",
            "Aulos",
            "Bagpipe",
            "Balaban",
            "Bandoneón",
            "Bansuri",
            "Baritone horn",
            "Baritone voice",
            "Bassoon",
            "Bawu",
            "Bayan",
            "Bazooka",
            "Beatboxing",
            "Bifora",
            "Birbynė",
            "Blul",
            "Blown bottle",
            "Bombarde",
            "Buccina",
            "Bugle",
            "Bullroarer",
            "Calliope",
            "Castrato",
            "Chalumeau",
            "Cimbasso",
            "Clarinet",
            "Clarytone",
            "Concertina",
            "Conch",
            "Cornamuse",
            "Cornet",
            "Cornett",
            "Cornu",
            "Corrugaphone",
            "Countertenor",
            "Cromorne",
            "Crumhorn",
            "Danso",
            "Death growl",
            "Didgeridoo",
            "Diple (or dvojnice)",
            "Dizi",
            "Double bell euphonium",
            "Doulophone/cuprophone",
            "Duduk",
            "Dulcian",
            "Dulzaina",
            "Dung-Dkar",
            "Dzhamara",
            "English horn",
            "Euphonium",
            "Falsetto",
            "Fife",
            "Firebird (trumpet)",
            "Fiscorn",
            "Flabiol",
            "Flageolet",
            "Flatt trumpet",
            "Flugelhorn",
            "Flumpet",
            "Flutina",
            "Flute",
            "Folgerphone",
            "French horn",
            "Fujara",
            "Gaida",
            "Gaita gastoreña",
            "Garmon",
            "Gemshorn",
            "Gralla",
            "Guan",
            "Guanzi",
            "Houguan",
            "Hano",
            "Harmoneon",
            "Harmonica",
            "Harmonium",
            "Heckelphone",
            "English horn",
            "Helicon",
            "Horagai",
            "Hosaphone",
            "Hotchiku",
            "Hulusi",
            "Hun",
            "Inci",
            "Irish flute",
            "Jug",
            "Kagurabue",
            "Kalaleng",
            "Kaval",
            "Kazoo",
            "Kèn bầu",
            "Key bugle",
            "Khene",
            "Khloy",
            "Khlui",
            "Komabue",
            "Koncovka",
            "Kortholt",
            "Koudi",
            "Kuhlohorn",
            "Launeddas",
            "Livenka",
            "Lur",
            "Lusheng",
            "Lituus",
            "Mellophone",
            "Melodica",
            "Melodeon",
            "Mezzo-soprano",
            "Mijwiz",
            "Mizmar",
            "Mizwad",
            "Musette de cour",
            "Nadaswaram",
            "Nagak",
            "Natural trumpet",
            "Ney",
            "Nguru",
            "Nohkan",
            "Nose flute",
            "Nplooj",
            "Nulophone",
            "Oboe",
            "aerophones",
            "Ocarina",
            "Octavin",
            "Ophicleide",
            "Paixiao",
            "Palendag",
            "Pan flute",
            "Pasiyak or water whistle",
            "Pavari",
            "Pibgorn",
            "Picco pipe",
            "Piccolo",
            "Piccolo trumpet",
            "Pipe organ",
            "Pitch pipe",
            "Pocket cornet",
            "Pocket trumpet",
            "Post horn",
            "Pu",
            "Pulalu",
            "Qeej",
            "Quena",
            "Quinticlave",
            "Raj",
            "Rackett",
            "Ralé-poussé",
            "Rapping",
            "Rauschpfeife",
            "Recorder",
            "Garklein",
            "Sopranino",
            "Descant",
            "Treble or alto",
            "Tenor",
            "Bass",
            "Great bass",
            "Contra bass",
            "Subcontra bass",
            "Sub-subcontrabass",
            "Venova",
            "Reed contrabass",
            "Reed organ",
            "Rhaita",
            "Robero",
            "Roman tuba",
            "Ryuteki",
            "Sac de gemecs",
            "Sackbut",
            "Saenghwang",
            "Samponia",
            "Saratovskaya garmonika",
            "Sarrusophone",
            "Saxophone",
            "Saxhorn",
            "Saxotromba",
            "Saxtuba",
            "Scat singing",
            "Schwyzerörgeli",
            "Serpent",
            "Shakuhachi",
            "Shankha",
            "Shawm",
            "Shehnai",
            "Sheng",
            "Shinobue",
            "Shofar",
            "Shō",
            "Shvi",
            "Siku",
            "Siren",
            "Slide trumpet",
            "Sneng",
            "Sodina",
            "Sopila",
            "Soprano",
            "Sorna",
            "Sousaphone",
            "Sralai",
            "Sudrophone",
            "Suling",
            "Suona",
            "Laba",
            "Haidi",
            "Superbone",
            "Swordblade",
            "Tabor pipe",
            "Taepyeongso",
            "Tarogato",
            "Tenor",
            "Tenora",
            "Throat singing",
            "Tible",
            "Tin whistle",
            "Toasting",
            "Tonette",
            "Trikiti",
            "Trombone",
            "Tromboon",
            "Trompeta china",
            "Trumpet",
            "Tuba",
            "Tube trumpet",
            "Tumpong",
            "Tungso",
            "Tutek",
            "Txistu",
            "Uilleann pipes",
            "Venu",
            "Vibrandoneon",
            "Vienna horn",
            "Vocal percussion",
            "Vuvuzela",
            "Wagner tuba",
            "Washint",
            "Flute",
            "Whip",
            "Pea whistle",
            "Steam whistle",
            "Train whistle",
            "Willow flute",
            "Xeremia",
            "Xiao",
            "Xun",
            "Yodel",
            "Yotar",
            "Yu",
            "Zhaleika",
            "Zufolo",
            "Zugtrompette",
            "Zurna",
            "Surnay",
        ],
    },
    {
        "category": "strings",
        "instruments": [
            "Adungu",
            "Aeolian harp",
            "Ajaeng",
            "Akkordolia",
            "Algerian mandole",
            "Angélique",
            "Appalachian dulcimer",
            "Arbajo",
            "Archlute",
            "Arpeggione",
            "Autoharp",
            "Bağlama",
            "Bajo sexto",
            "Balalaika",
            "Bandola",
            "Bandolin",
            "Bandolón",
            "Bandura",
            "Bandora",
            "Bandurria",
            "Banhu",
            "Banjo",
            "Banjo ukulele",
            "Barbat",
            "Baryton",
            "Berimbau",
            "Bipa",
            "Biwa",
            "Bordonua",
            "Bouzouki",
            "Buzuq",
            "Carimba",
            "Cavaquinho",
            "Cello",
            "Chapman stick",
            "Charangos",
            "Chitarra battente",
            "Chitarra Italiana",
            "Choghur",
            "Cimbalom",
            "Electric cymbalum",
            "Cimboa",
            "Citole",
            "Cittern",
            "Clavichord",
            "Clavinet",
            "Concheras",
            "Contraguitar",
            "Crwth (Crowd)",
            "Cuatro",
            "Cümbüş",
            "Đàn bầu",
            "Đàn đáy",
            "Đàn gáo",
            "Đàn nguyệt",
            "Đàn tam thập lục",
            "Đàn tranh",
            "Đàn tỳ bà",
            "Diddley bow",
            "Dihu",
            "Dombra",
            "Domra",
            "Doshpuluur",
            "Dotara",
            "Double bass",
            "Dreadnought",
            "Dulcimer",
            "Dutar",
            "Duxianqin",
            "Ektara",
            "Erhu",
            "Erxian",
            "Esraj",
            "Faglong/Fuglung",
            "Fegereng",
            "Fiddle",
            "Gaohu",
            "Gayageum",
            "Geomungo",
            "Gittern",
            "Gottuvadhyam",
            "Guitars",
            "Gusli",
            "Guqin",
            "Guzheng",
            "Haegeum",
            "Hammered dulcimer",
            "Hardanger fiddle",
            "Harmonico",
            "Harp",
            "Harpsichord",
            "Hegelong",
            "Huapanguera",
            "Huluhu",
            "Huqin",
            "Hurdy-gurdy",
            "Igil",
            "Irish bouzouki",
            "Janzi",
            "Jarana jarocho",
            "Jarana huasteca",
            "Jarana mosquito",
            "Jarana segunda",
            "Jarana tercera",
            "Jiaohu",
            "Kabosy",
            "Kadlong",
            "Kamancha",
            "Kantele",
            "Kemenche",
            "Khim",
            "Kobza",
            "Kokle",
            "Kokyū",
            "Komuz",
            "Kora",
            "Koto",
            "Kubing",
            "Kudyapi",
            "Kwitra",
            "Langeleik",
            "Laouto",
            "Laruan",
            "Laúd",
            "Lavta",
            "Leiqin",
            "Leona",
            "Lirone",
            "Liuqin",
            "Lokanga",
            "Lute",
            "Lute guitar",
            "Lyra",
            "Lyre",
            "Maguhu",
            "Mandobass",
            "Mandola",
            "Mandolin",
            "Mandolute",
            "Mandora",
            "Mandore",
            "Marovany",
            "Mejoranera",
            "Mexican vihuela",
            "Mohan veena",
            "Moraharpa",
            "Morin khuur",
            "Musical bow",
            "Nyckelharpa",
            "Octobass",
            "Oud",
            "Paqin",
            "Piano",
            "Pipa",
            "Piwancha",
            "Pochette",
            "Portuguese guitar",
            "Psaltery",
            "Qanun",
            "Qinqin",
            "Rabeca",
            "Rajão",
            "Ravanahatha",
            "Rebab",
            "Rebec",
            "Requinto jarocho",
            "Rubab",
            "Ruan",
            "Gaoyinruan",
            "Xiaoruan",
            "Zhongruan",
            "Daruan",
            "Diyinruan",
            "Rudra vina",
            "Sallameh",
            "Sanshin",
            "Santoor",
            "Sanxian",
            "Sarangi",
            "Šargija",
            "Sarod",
            "Saung",
            "Saw sam sai",
            "Se",
            "Seul",
            "Setar (lute)",
            "Shamisen",
            "Sintir",
            "Sitar",
            "Sitarla",
            "Surbahar",
            "Swarmandal",
            "Tamburica",
            "Tambur",
            "Tanpura",
            "Tar (lute)",
            "Tea chest bass",
            "Tembûr",
            "Theorbo",
            "Timple",
            "Tiple",
            "Tovshuur",
            "Tres",
            "Tres Cubano",
            "Tres Puerto Rico",
            "Tricordia",
            "Tro",
            "Trumpet marine/tromba marina",
            "Tsymbaly",
            "Tuhu",
            "Tzouras",
            "Ukulele",
            "Ukelin",
            "Valiha",
            "Veena",
            "Vichitra veena",
            "Vielle",
            "Vihuela",
            "Viola",
            "Violin",
            "Violone",
            "Violotta",
            "Walaycho",
            "Waldzither",
            "Washtub bass",
            "Whamola",
            "Wheelharp",
            "Xalam/Khalam",
            "Yaylı tambur",
            "Yangqin",
            "Yazheng",
            "Yehu",
            "Yelatáj chos woley",
            "Yueqin",
            "Zhongruan",
            "Zhonghu",
            "Zhu",
            "Zhengni",
            "Zhuihu",
            "Zither",
        ],
    },
    {
        "category": "electronics",
        "instruments": [
            "AlphaSphere",
            "Audiocubes",
            "Bass pedals",
            "Continuum Fingerboard",
            "Croix Sonore",
            "Denis d'or",
            "Dubreq stylophone",
            "Drum machine",
            "Eigenharp",
            "Electric guitar",
            "Electronic keyboard",
            "Electronic organ",
            "EWI",
            "Fingerboard synthesizer",
            "Hammond organ",
            "Jammer keyboard",
            "Keyboard",
            "Keytar",
            "Kraakdoos (cracklebox)",
            "Laser harp",
            "Mellotron",
            "MIDI keyboard",
            "Omnichord",
            "Ondes Martenot",
            "Otamatone",
            "Sampler",
            "Seaboard",
            "Skoog",
            "Synclavier",
            "Synthesizer",
            "Teleharmonium",
            "Tembûr",
            "Tenori-on",
            "Theremin",
            "Turntable",
        ],
    },
]
