"""
Raw data for faker_music module (music.py) to mine from.
Data is presented in one big list of dicts, each dict
corresponding to a "genre object":
{
    "genre": "<genre_name>",
    "subgenres": [
        "<subgenre1>",
        "<subgenre2>",
        "<subgenre3>",
        ...
    ]
}

This data was harvested on 2021-05-14, from 
https://www.musicgenreslist.com/
Author maintains code to format copy/pasted data;
please ask for link to gist
"""

genre_list = [
    {
        "genre": "Alternative",
        "subgenres": [
            "Art Punk",
            "Alternative Rock",
            "Britpunk",
            "College Rock",
            "Crossover Thrash",
            "Crust Punk",
            "Emotional Hardcore",
            "Experimental Rock",
            "Folk Punk",
            "Goth",
            "Grunge",
            "Hardcore Punk",
            "Hard Rock",
            "Indie Rock",
            "Lo-fi",
            "Musique Concrète",
            "New Wave",
            "Progressive Rock",
            "Punk",
            "Shoegaze",
            "Steampunk",
        ],
    },
    {"genre": "Anime", "subgenres": []},
    {
        "genre": "Blues",
        "subgenres": [
            "Acoustic Blues",
            "African Blues",
            "Blues Rock",
            "Blues Shouter",
            "British Blues",
            "Canadian Blues",
            "Chicago Blues",
            "Classic Blues",
            "Classic Female Blues",
            "Contemporary Blues",
            "Contemporary R&B",
            "Country Blues",
            "Dark Blues",
            "Delta Blues",
            "Detroit Blues",
            "Doom Blues",
            "Electric Blues",
            "Folk Blues",
            "Gospel Blues",
            "Harmonica Blues",
            "Hill Country Blues",
            "Hokum Blues",
            "Jazz Blues",
            "Jump Blues",
            "Kansas City Blues",
            "Louisiana Blues",
            "Memphis Blues",
            "Modern Blues",
            "New Orlean Blues",
            "NY Blues",
            "Piano Blues",
            "Piedmont Blues",
            "Punk Blues",
            "Ragtime Blues",
            "Rhythm Blues",
            "Soul Blues",
            "St. Louis Blues",
            "Soul Blues",
            "Swamp Blues",
            "Texas Blues",
            "Urban Blues",
            "Vandeville",
            "West Coast Blues",
            "Zydeco",
        ],
    },
    {"genre": "Children’s Music", "subgenres": ["Lullabies", "Sing-Along", "Stories"]},
    {
        "genre": "Classical",
        "subgenres": [
            "Avant-Garde",
            "Ballet",
            "Baroque",
            "Cantata",
            "Chamber Music",
            "Chant",
            "Choral",
            "Classical Crossover",
            "Concerto",
            "Concerto Grosso",
            "Contemporary Classical",
            "Early Music",
            "Expressionist",
            "High Classical",
            "Impressionist",
            "Mass Requiem",
            "Medieval",
            "Minimalism",
            "Modern Composition",
            "Modern Classical",
            "Opera",
            "Oratorio",
            "Orchestral",
            "Organum",
            "Renaissance",
            "Romantic",
            "Romantic",
            "Sonata",
            "Symphonic",
            "Symphony",
            "Wedding Music",
        ],
    },
    {
        "genre": "Comedy",
        "subgenres": ["Novelty", "Parody Music", "Stand-up Comedy", "Vaudeville"],
    },
    {"genre": "Commercial", "subgenres": ["Jingles", "TV Themes"]},
    {
        "genre": "Country",
        "subgenres": [
            "Alternative Country",
            "Americana",
            "Australian Country",
            "Bakersfield Sound",
            "Bluegrass",
            "Blues Country",
            "Cajun Fiddle Tunes",
            "Christian Country",
            "Classic Country",
            "Close Harmony",
            "Contemporary Bluegrass",
            "Contemporary Country",
            "Country Gospel",
            "Country Pop",
            "Country Rap",
            "Country Rock",
            "Country Soul",
            "Cowpunk",
            "Dansband",
            "Honky Tonk",
            "Franco-Country",
            "Gulf and Western",
            "Hellbilly Music",
            "Honky Tonk",
            "Instrumental Country",
            "Lubbock Sound",
            "Nashville Sound",
            "Neotraditional Country",
            "Outlaw Country",
            "Progressive",
            "Psychobilly",
            "Punkabilly",
            "Red Dirt",
            "Sertanejo",
            "Texas County",
            "Traditional Bluegrass",
            "Traditional Country",
            "Truck-Driving Country",
            "Urban Cowboy",
            "Western Swing",
            "Zydeco",
        ],
    },
    {
        "genre": "Dance )",
        "subgenres": [
            "Club",
            "Breakcore",
            "Breakbeat",
            "Breakstep",
            "Brostep",
            "Chillstep",
            "Deep House",
            "Dubstep",
            "Eurodance",
            "Electro House",
            "Electroswing",
            "Exercise",
            "Future Garage",
            "Garage",
            "Glitch Hop",
            "Glitch Pop",
            "Grime",
            "Hardcore",
            "Hard Dance",
            "Hi-NRG",
            "Horrorcore",
            "House",
            "Jackin House",
            "Jungle",
            "Liquid Dub",
            "Regstep",
            "Speedcore",
            "Techno",
            "Trance",
            "Trap",
        ],
    },
    {"genre": "Disney", "subgenres": []},
    {
        "genre": "Easy Listening",
        "subgenres": [
            "Background",
            "Bop",
            "Elevator",
            "Furniture",
            "Lounge",
            "Middle of the Road",
            "Swing",
        ],
    },
    {
        "genre": "Electronic",
        "subgenres": [
            "2-Step",
            "8bit",
            "Ambient",
            "Asian Underground",
            "Bassline",
            "Chillwave",
            "Chiptune",
            "Crunk",
            "Downtempo",
            "Drum & Bass",
            "Electro",
            "Electro-swing",
            "Electroacoustic",
            "Electronica",
            "Electronic Rock",
            "Eurodance",
            "Hardstyle",
            "Hi-Nrg",
            "IDM/Experimental",
            "Industrial",
            "Trip Hop",
            "UK Garage",
        ],
    },
    {"genre": "Enka", "subgenres": []},
    {"genre": "French Pop", "subgenres": []},
    {
        "genre": "Folk Music",
        "subgenres": [
            "American Folk Revival",
            "Anti-Folk",
            "British Folk Revival",
            "Contemporary Folk",
            "Filk Music",
            "Freak Folk",
            "Indie Folk",
            "Industrial Folk",
            "Neofolk",
            "Progressive Folk",
            "Psychedelic Folk",
            "Sung Poetry",
            "Techno-Folk",
        ],
    },
    {"genre": "German Folk", "subgenres": []},
    {"genre": "German Pop", "subgenres": []},
    {"genre": "Fitness & Workout", "subgenres": []},
    {
        "genre": "Hip-Hop/Rap",
        "subgenres": [
            "Alternative Rap",
            "Avant-Garde",
            "Bounce",
            "Chap Hop",
            "Christian Hip Hop",
            "Conscious Hip Hop",
            "Country-Rap",
            "Crunkcore",
            "Cumbia Rap",
            "Dirty South",
            "East Coast",
            "Freestyle Rap",
            "G-Funk",
            "Gangsta Rap",
            "Golden Age",
            "Hardcore Rap",
            "Hip-Hop",
            "Hip Pop",
            "Hyphy",
            "Industrial Hip Hop",
            "Instrumental Hip Hop",
            "Jazz Rap",
            "Latin Rap",
            "Low Bap",
            "Lyrical Hip Hop",
            "Merenrap",
            "Midwest Hip Hop",
            "Motswako",
            "Nerdcore",
            "New Jack Swing",
            "New School Hip Hop",
            "Old School Rap",
            "Rap",
            "Turntablism",
            "Underground Rap",
            "West Coast Rap",
        ],
    },
    {
        "genre": "Holiday",
        "subgenres": [
            "Chanukah",
            "Christmas",
            "Christmas: Children’s",
            "Christmas: Classic",
            "Christmas: Classical",
            "Christmas: Comedy",
            "Christmas: Jazz",
            "Christmas: Modern",
            "Christmas: Pop",
            "Christmas: R&B",
            "Christmas: Religious",
            "Christmas: Rock",
            "Easter",
            "Halloween",
            "Holiday: Other",
            "Thanksgiving",
        ],
    },
    {"genre": "Indie Pop", "subgenres": []},
    {
        "genre": "Industrial",
        "subgenres": [
            "Aggrotech",
            "Coldwave",
            "Cybergrind",
            "Dark Electro",
            "Death Industrial",
            "Electro-Industrial",
            "Electronic Body Music",
            "Industrial Metal",
            "Industrial Rock",
            "Noise",
            "Witch House",
        ],
    },
    {
        "genre": "Inspirational – Christian & Gospel",
        "subgenres": [
            "CCM",
            "Christian Metal",
            "Christian Pop",
            "Christian Rap",
            "Christian Rock",
            "Classic Christian",
            "Contemporary Gospel",
            "Gospel",
            "Christian & Gospel",
            "Praise & Worship",
            "Qawwali",
            "Southern Gospel",
            "Traditional Gospel",
        ],
    },
    {"genre": "Instrumental", "subgenres": ["March"]},
    {"genre": "J-Pop", "subgenres": ["J-Rock", "J-Synth", "J-Ska", "J-Punk"]},
    {
        "genre": "Jazz",
        "subgenres": [
            "Acid Jazz",
            "Avant-Garde Jazz",
            "Bebop",
            "Big Band",
            "Blue Note",
            "Contemporary Jazz",
            "Cool",
            "Crossover Jazz",
            "Dixieland",
            "Ethio-jazz",
            "Fusion",
            "Gypsy Jazz",
            "Hard Bop",
            "Latin Jazz",
            "Mainstream Jazz",
            "Ragtime",
            "Smooth Jazz",
            "Trad Jazz",
            "Third Stream",
            "Jazz-Funk",
            "Free Jazz",
            "Modal Jazz",
        ],
    },
    {"genre": "K-Pop", "subgenres": []},
    {"genre": "Karaoke", "subgenres": []},
    {"genre": "Kayokyoku", "subgenres": []},
    {
        "genre": "Latin",
        "subgenres": [
            "Alternativo & Rock Latino",
            "Argentine tango",
            "Bachata",
            "Baithak Gana",
            "Baladas y Boleros",
            "Bolero",
            "Bossa Nova",
            "Brazilian",
            "Chicha",
            "Criolla",
            "Contemporary Latin",
            "Cumbia",
            "Flamenco",
            "Huayno",
            "Latin Jazz",
            "Mariachi",
            "Merengue Típico",
            "Nuevo Flamenco",
            "Pop Latino",
            "Portuguese fado",
            "Punta",
            "Punta Rock",
            "Ranchera",
            "Raíces",
            "Raison",
            "Reggaeton y Hip-Hop",
            "Regional Mexicano",
            "Salsa y Tropical",
            "Soca",
            "Son",
            "Tejano",
            "Timba",
            "Twoubadou",
            "Zouk",
        ],
    },
    {
        "genre": "Metal",
        "subgenres": [
            "Heavy Metal",
            "Speed Metal",
            "Thrash Metal",
            "Power Metal",
            "Death Metal",
            "Black Metal",
            "Pagan Metal",
            "Viking Metal",
            "Folk Metal",
            "Symphonic Metal",
            "Gothic Metal",
            "Glam Metal",
            "Hair Metal",
            "Doom Metal",
            "Groove Metal",
            "Industrial Metal",
            "Modern Metal",
            "Neoclassical Metal",
            "New Wave Of British Heavy Metal",
            "Post Metal",
            "Progressive Metal",
            "Avantgarde Metal",
            "Sludge",
            "Djent",
            "Drone",
            "Kawaii Metal",
            "Pirate Metal",
            "Nu Metal",
            "Neue Deutsche Härte",
            "Math Metal",
            "Crossover",
            "Grindcore",
            "Hardcore",
            "Metalcore",
            "Deathcore",
            "Post Hardcore",
            "Mathcore",
        ],
    },
    {
        "genre": "New Age",
        "subgenres": [
            "Ambient",
            "Environmental",
            "Healing",
            "Meditation",
            "Nature",
            "Relaxation",
            "Travel",
            "Yoga",
        ],
    },
    {"genre": "Opera", "subgenres": []},
    {
        "genre": "Pop",
        "subgenres": [
            "Adult Contemporary",
            "Arab Pop",
            "Baroque",
            "Britpop",
            "Bubblegum Pop",
            "Chamber Pop",
            "Chanson",
            "Christian Pop",
            "Classical Crossover",
            "Europop",
            "Dance Pop",
            "Dream Pop",
            "Electro Pop",
            "Iranian Pop",
            "Jangle Pop",
            "Latin Ballad",
            "Levenslied",
            "Louisiana Swamp Pop",
            "Mexican Pop",
            "Motorpop",
            "New Romanticism",
            "Orchestral Pop",
            "Pop Rap",
            "Popera",
            "Pop/Rock",
            "Pop Punk",
            "Power Pop",
            "Psychedelic Pop",
            "Schlager",
            "Soft Rock",
            "Sophisti-Pop",
            "Space Age Pop",
            "Sunshine Pop",
            "Surf Pop",
            "Synthpop",
            "Teen Pop",
            "Traditional Pop Music",
            "Turkish Pop",
            "Vispop",
            "Wonky Pop",
        ],
    },
    {"genre": "Post-Disco", "subgenres": ["Boogie", "Dance-pop"]},
    {
        "genre": "Progressive",
        "subgenres": [
            "Progressive House",
            "Progressive Breaks",
            "Progressive Drum & Bass",
            "Progressive Techno",
            "Trance",
        ],
    },
    {
        "genre": "R&B/Soul",
        "subgenres": [
            "Contemporary R&B",
            "Disco",
            "Doo Wop",
            "Funk",
            "Modern Soul",
            "Motown",
            "Neo-Soul",
            "Northern Soul",
            "Psychedelic Soul",
            "Quiet Storm",
            "Soul",
            "Soul Blues",
            "Southern Soul",
        ],
    },
    {
        "genre": "Reggae",
        "subgenres": [
            "2-Tone",
            "Dancehall",
            "Dub",
            "Roots Reggae",
            "Reggae Fusion",
            "Reggae en Español",
            "Lovers Rock",
            "Raggamuffin",
            "Ska",
        ],
    },
    {
        "genre": "Rock",
        "subgenres": [
            "Acid Rock",
            "Adult-Oriented Rock",
            "Afro Punk",
            "Adult Alternative",
            "Alternative Rock",
            "American Traditional Rock",
            "Anatolian Rock",
            "Arena Rock",
            "Art Rock",
            "Blues-Rock",
            "British Invasion",
            "Cock Rock",
            "Death Metal",
            "Doom Metal",
            "Glam Rock",
            "Gothic Metal",
            "Grind Core",
            "Hair Metal",
            "Hard Rock",
            "Math Metal",
            "Math Rock",
            "Metal",
            "Metal Core",
            "Noise Rock",
            "Jam Bands",
            "Post Punk",
            "Prog-Rock/Art Rock",
            "Progressive Metal",
            "Psychedelic",
            "Rock & Roll",
            "Rockabilly",
            "Roots Rock",
            "Singer/Songwriter",
            "Southern Rock",
            "Spazzcore",
            "Stoner Metal",
            "Surf",
            "Technical Death Metal",
            "Tex-Mex",
            "Thrash Metal",
            "Time Lord Rock  ~",
            "Trip-hop",
        ],
    },
    {
        "genre": "Singer/Songwriter",
        "subgenres": [
            "Alternative Folk",
            "Contemporary Folk",
            "Contemporary Singer/Songwriter",
            "Indie Folk",
            "Folk-Rock",
            "Love Song",
            "New Acoustic",
            "Traditional Folk",
        ],
    },
    {
        "genre": "Soundtrack",
        "subgenres": [
            "Foreign Cinema",
            "Movie Soundtrack",
            "Musicals",
            "Original Score",
            "Soundtrack",
            "TV Soundtrack",
        ],
    },
    {"genre": "Spoken Word", "subgenres": []},
    {
        "genre": "Tejano",
        "subgenres": [
            "Chicano",
            "Classic",
            "Conjunto",
            "Conjunto Progressive",
            "New Mex",
            "Tex-Mex",
        ],
    },
    {
        "genre": "Tex-Mex",
        "subgenres": [
            "Chicano",
            "Classic",
            "Conjunto",
            "Conjunto Progressive",
            "New Mex",
            "Tex-Mex",
        ],
    },
    {
        "genre": "Vocal",
        "subgenres": [
            "A cappella",
            "Barbershop",
            "Cantique",
            "Doo-wop",
            "Gregorian Chant",
            "Standards",
            "Traditional Pop",
            "Vocal Jazz",
            "Vocal Pop",
        ],
    },
    {
        "genre": "World",
        "subgenres": [
            "Africa",
            "Asia",
            "Australia",
            "Cajun",
            "Calypso",
            "Caribbean",
            "Carnatic",
            "Celtic",
            "Celtic Folk",
            "Contemporary Celtic",
            "Coupé-décalé  – Congo",
            "Dangdut",
            "Drinking Songs",
            "Drone",
            "Europe",
            "France",
            "Hawaii",
            "Japan",
            "Klezmer",
            "Mbalax  – Senegal",
            "Middle East",
            "North America",
            "Ode",
            "Piphat  – Thailand",
            "Polka",
            "Soca",
            "South Africa",
            "South America",
            "Southeast Asia",
            "Traditional Celtic",
            "Worldbeat",
            "Zydeco",
        ],
    },
]
